@@ -1,8 +1,9 @@
 package Net::GitHub::V3;
 
-use Any::Moose;
+use Moo;
+use Types::Standard qw(InstanceOf);
 
-our $VERSION = '0.40';
+our $VERSION = '0.60';
 our $AUTHORITY = 'cpan:FAYLAND';
 
 with 'Net::GitHub::V3::Query';
@@ -14,12 +15,15 @@ use Net::GitHub::V3::PullRequests;
 use Net::GitHub::V3::Orgs;
 use Net::GitHub::V3::GitData;
 use Net::GitHub::V3::Gists;
+use Net::GitHub::V3::OAuth;
+use Net::GitHub::V3::Events;
+use Net::GitHub::V3::Search;
 
 has '+is_main_module' => (default => 1);
 
 has 'user' => (
     is => 'rw',
-    isa => 'Net::GitHub::V3::Users',
+    isa => InstanceOf['Net::GitHub::V3::Users'],
     lazy => 1,
     default => sub {
         my $self = shift;
@@ -29,7 +33,7 @@ has 'user' => (
 
 has 'org' => (
     is => 'rw',
-    isa => 'Net::GitHub::V3::Orgs',
+    isa => InstanceOf['Net::GitHub::V3::Orgs'],
     lazy => 1,
     default => sub {
         my $self = shift;
@@ -39,7 +43,7 @@ has 'org' => (
 
 has 'gist' => (
     is => 'rw',
-    isa => 'Net::GitHub::V3::Gists',
+    isa => InstanceOf['Net::GitHub::V3::Gists'],
     lazy => 1,
     default => sub {
         my $self = shift;
@@ -49,7 +53,7 @@ has 'gist' => (
 
 has 'repos' => (
     is => 'rw',
-    isa => 'Net::GitHub::V3::Repos',
+    isa => InstanceOf['Net::GitHub::V3::Repos'],
     lazy => 1,
     predicate => 'is_repos_init',
     default => sub {
@@ -60,7 +64,7 @@ has 'repos' => (
 
 has 'issue' => (
     is => 'rw',
-    isa => 'Net::GitHub::V3::Issues',
+    isa => InstanceOf['Net::GitHub::V3::Issues'],
     lazy => 1,
     predicate => 'is_issue_init',
     default => sub {
@@ -71,7 +75,7 @@ has 'issue' => (
 
 has 'pull_request' => (
     is => 'rw',
-    isa => 'Net::GitHub::V3::PullRequests',
+    isa => InstanceOf['Net::GitHub::V3::PullRequests'],
     lazy => 1,
     predicate => 'is_pull_request_init',
     default => sub {
@@ -82,7 +86,7 @@ has 'pull_request' => (
 
 has 'git_data' => (
     is => 'rw',
-    isa => 'Net::GitHub::V3::GitData',
+    isa => InstanceOf['Net::GitHub::V3::GitData'],
     lazy => 1,
     predicate => 'is_git_data_init',
     default => sub {
@@ -91,8 +95,37 @@ has 'git_data' => (
     },
 );
 
-no Any::Moose;
-__PACKAGE__->meta->make_immutable;
+has 'oauth' => (
+    is => 'rw',
+    isa => InstanceOf['Net::GitHub::V3::OAuth'],
+    lazy => 1,
+    default => sub {
+        my $self = shift;
+        return Net::GitHub::V3::OAuth->new( $self->args_to_pass );
+    },
+);
+
+has 'event' => (
+    is => 'rw',
+    isa => InstanceOf['Net::GitHub::V3::Events'],
+    lazy => 1,
+    default => sub {
+        my $self = shift;
+        return Net::GitHub::V3::Events->new( $self->args_to_pass );
+    },
+);
+
+has 'search' => (
+    is => 'rw',
+    isa => InstanceOf['Net::GitHub::V3::Search'],
+    lazy => 1,
+    default => sub {
+        my $self = shift;
+        return Net::GitHub::V3::Search->new( $self->args_to_pass );
+    },
+);
+
+no Moo;
 
 1;
 __END__
@@ -137,7 +170,7 @@ There are two ways to authenticate through GitHub API v3:
 =item login/pass
 
     my $gh = Net::GitHub::V3->new( login => $ENV{GITHUB_USER}, pass => $ENV{GITHUB_PASS} );
-    
+
 =item access_token
 
     my $gh = Net::GitHub->new( access_token => $ENV{GITHUB_ACCESS_TOKEN} );
@@ -159,7 +192,7 @@ return raw L<HTTP::Response> object
         # login/pass or access_token
         raw_string => 1
     );
-    
+
 return L<HTTP::Response> response content as string
 
 =head3 api_throttle
@@ -178,6 +211,26 @@ from the API. By switching B<RaiseError> on you can make the be turned into
 exceptions instead, so that you don't have to check for error response after
 every call.
 
+=head3 next_url, last_url, prev_url, first_url
+
+Any methods which return multiple results I<may> be paginated. After performing
+a query you should check to see if there are more results. These attributes will
+be reset for each query.
+
+The predicates to check these attributes are C<has_next_page>, C<has_last_page>,
+C<has_prev_page> and C<has_first_page>.
+
+See Github's documentation: L<http://developer.github.com/v3/#pagination>
+
+The C<per_page> parameter mentioned in their docs is B<NOT> supported by this module.
+
+  my @issues = $gh->issue->repos_issues;
+  while ($gh->issue->has_next_page) {
+      push @issues, $gh->issue->query($gh->issue->next_url);
+      ## OR ##
+      push @issues, $gh->issue->next_page);
+  }
+
 =head2 METHODS
 
 =head3 query($method, $url, $data)
@@ -188,12 +241,17 @@ every call.
 
 query API directly
 
+=head3 next_page
+
+When the results have been paginated, C<next_page> is sugar for the common case
+of iterating through all the pages in order. It simply calls C<query> with the C<next_url>.
+
 =head3 set_default_user_repo
 
     $gh->set_default_user_repo('fayland', 'perl-net-github'); # take effects for all $gh->
     $gh->repos->set_default_user_repo('fayland', 'perl-net-github'); # take effects on $gh->repos
 
-B<To ease the keyboard, we provied two ways to call any method which starts with :user/:repo>
+B<To ease the keyboard, we provided two ways to call any method which starts with :user/:repo>
 
 1. SET user/repos before call methods below
 
@@ -240,7 +298,7 @@ L<Net::GitHub::V3::PullRequests>
 =head3 org
 
     my @orgs   = $gh->org->orgs;
-    
+
 L<Net::GitHub::V3::Orgs>
 
 =head3 git_data
@@ -251,9 +309,21 @@ L<Net::GitHub::V3::GitData>
 
 L<Net::GitHub::V3::Gists>
 
+=head3 oauth
+
+L<Net::GitHub::V3::OAuth>
+
+=head3 event
+
+L<Net::GitHub::V3::Events>
+
+=head3 search
+
+L<Net::GitHub::V3::Search>
+
 =head1 SEE ALSO
 
-L<Any::Moose>, L<Pithub>
+L<Pithub>
 
 =head1 AUTHOR & COPYRIGHT & LICENSE
 
