@@ -1,48 +1,49 @@
 package Net::GitHub::V3::Query;
 
-use Any::Moose 'Role';
-
-our $VERSION = '0.40';
+our $VERSION = '0.60';
 our $AUTHORITY = 'cpan:FAYLAND';
 
 use URI;
 use JSON::Any;
-use WWW::Mechanize::GZip;
 use MIME::Base64;
+use LWP::UserAgent;
 use HTTP::Request;
 use Carp qw/croak/;
 use URI::Escape;
+use Types::Standard qw(Str Bool InstanceOf);
+
+use Moo::Role;
 
 # configurable args
 
 # Authentication
-has 'login'  => ( is => 'rw', isa => 'Str', predicate => 'has_login' );
-has 'pass'  => ( is => 'rw', isa => 'Str', predicate => 'has_pass' );
-has 'access_token' => ( is => 'rw', isa => 'Str', predicate => 'has_access_token' );
+has 'login'  => ( is => 'rw', isa => Str, predicate => 'has_login' );
+has 'pass'  => ( is => 'rw', isa => Str, predicate => 'has_pass' );
+has 'access_token' => ( is => 'rw', isa => Str, predicate => 'has_access_token' );
 
 # return raw unparsed JSON
-has 'raw_string' => (is => 'rw', isa => 'Bool', default => 0);
-has 'raw_response' => (is => 'rw', isa => 'Bool', default => 0);
+has 'raw_string' => (is => 'rw', isa => Bool, default => 0);
+has 'raw_response' => (is => 'rw', isa => Bool, default => 0);
 
 has 'api_url' => (is => 'ro', default => 'https://api.github.com');
-has 'api_throttle' => ( is => 'rw', isa => 'Bool', default => 1 );
+has 'api_throttle' => ( is => 'rw', isa => Bool, default => 1 );
 
 has 'upload_url' => (is => 'ro', default => 'https://uploads.github.com');
 
 # pagination
-has 'next_url'  => ( is => 'rw', isa => 'Str', predicate => 'has_next_page',  clearer => 'clear_next_url' );
-has 'last_url'  => ( is => 'rw', isa => 'Str', predicate => 'has_last_page',  clearer => 'clear_last_url' );
-has 'first_url' => ( is => 'rw', isa => 'Str', predicate => 'has_first_page', clearer => 'clear_first_url' );
-has 'prev_url'  => ( is => 'rw', isa => 'Str', predicate => 'has_prev_page',  clearer => 'clear_prev_url' );
+has 'next_url'  => ( is => 'rw', isa => Str, predicate => 'has_next_page',  clearer => 'clear_next_url' );
+has 'last_url'  => ( is => 'rw', isa => Str, predicate => 'has_last_page',  clearer => 'clear_last_url' );
+has 'first_url' => ( is => 'rw', isa => Str, predicate => 'has_first_page', clearer => 'clear_first_url' );
+has 'prev_url'  => ( is => 'rw', isa => Str, predicate => 'has_prev_page',  clearer => 'clear_prev_url' );
 
 # Error handle
-has 'RaiseError' => ( is => 'rw', isa => 'Bool', default => 1 );
+has 'RaiseError' => ( is => 'rw', isa => Bool, default => 1 );
 
 # optional
-has 'u'  => (is => 'rw', isa => 'Str');
-has 'repo' => (is => 'rw', isa => 'Str');
+has 'u'  => (is => 'rw', isa => Str);
+has 'repo' => (is => 'rw', isa => Str);
 
-has 'is_main_module' => (is => 'ro', isa => 'Bool', default => 0);
+has 'is_main_module' => (is => 'ro', isa => Bool, default => 0);
 sub set_default_user_repo {
     my ($self, $user, $repo) = @_;
 
@@ -79,12 +80,11 @@ sub args_to_pass {
 }
 
 has 'ua' => (
-    isa     => 'WWW::Mechanize::GZip',
+    isa     => InstanceOf['LWP::UserAgent'],
     is      => 'ro',
     lazy    => 1,
     default => sub {
-        my $self = shift;
-        return WWW::Mechanize::GZip->new(
+        LWP::UserAgent->new(
             agent       => "perl-net-github $VERSION",
             cookie_jar  => {},
             stack_depth => 1,
@@ -97,7 +97,7 @@ has 'ua' => (
 
 has 'json' => (
     is => 'ro',
-    isa => 'JSON::Any',
+    isa => InstanceOf['JSON::Any'],
     lazy => 1,
     default => sub {
         return JSON::Any->new( utf8 => 1 );
@@ -132,6 +132,7 @@ sub query {
 
     print STDERR ">>> $request_method $url\n" if $ENV{NG_DEBUG};
     my $req = HTTP::Request->new( $request_method, $url );
+    $req->accept_decodable;
     if ($data) {
         my $json = $self->json->objToJson($data);
         print STDERR ">>> $data\n" if $ENV{NG_DEBUG} and $ENV{NG_DEBUG} > 1;
@@ -149,12 +150,12 @@ sub query {
             < ($res->header('x-ratelimit-limit') || 60) / 2);
     }
 
-    print STDERR "<<< " . $ua->content . "\n" if $ENV{NG_DEBUG} and $ENV{NG_DEBUG} > 1;
-    return $ua->res if $self->raw_response;
-    return $ua->content if $self->raw_string;
+    print STDERR "<<< " . $res->decoded_content . "\n" if $ENV{NG_DEBUG} and $ENV{NG_DEBUG} > 1;
+    return $res if $self->raw_response;
+    return $res->decoded_content if $self->raw_string;
 
     if ($res->header('Content-Type') and $res->header('Content-Type') =~ 'application/json') {
-        my $json = $ua->content;
+        my $json = $res->decoded_content;
         $data = eval { $self->json->jsonToObj($json) };
         unless ($data) {
             # We tolerate bad JSON for errors,
@@ -167,7 +168,7 @@ sub query {
     }
 
     if ( $self->RaiseError ) {
-        croak $data->{message} if not $ua->success and ref $data eq 'HASH' and exists $data->{message}; # for 'Client Errors'
+        croak $data->{message} if not $res->is_success and ref $data eq 'HASH' and exists $data->{message}; # for 'Client Errors'
     }
 
     $self->_clear_pagination;
@@ -231,7 +232,12 @@ sub __build_methods {
         my $check_status = $v->{check_status};
         my $is_u_repo = $v->{is_u_repo}; # need auto shift u/repo
 
-        $package->meta->add_method( $m => sub {
+        my $glob = do {
+          no strict 'refs';
+          no warnings 'once';
+          *{"${package}::${m}"};
+        };
+        *$glob = sub {
             my $self = shift;
 
             # count how much %s inside u
@@ -257,11 +263,11 @@ sub __build_methods {
             } else {
                 return $self->query($method, $u, @qargs);
             }
-        } );
+        };
     }
 }
 
-no Any::Moose;
+no Moo::Role;
 
 1;
 __END__
@@ -274,7 +280,7 @@ Net::GitHub::V3::Query - Base Query role for Net::GitHub::V3
 
     package Net::GitHub::V3::XXX;
 
-    use Any::Moose;
+    use Moo;
     with 'Net::GitHub::V3::Query';
 
 =head1 DESCRIPTION
@@ -327,4 +333,4 @@ NG_DEBUG > 1 to view request/response string
 
 =head1 AUTHOR & COPYRIGHT & LICENSE
 
-Refer L<Net::GitHub>
\ No newline at end of file
+Refer L<Net::GitHub>
