@@ -1,6 +1,6 @@
 package Net::GitHub::V3::Repos;
 
-use Any::Moose;
+use Moo;
 
 our $VERSION = '0.60';
 our $AUTHORITY = 'cpan:FAYLAND';
@@ -75,6 +75,7 @@ sub upload_asset {
     my $ua = $self->ua;
     my $url = $self->upload_url . "/repos/$user/$repos/releases/$release_id/assets?name=" . uri_escape($name);
     my $req = HTTP::Request->new( 'POST', $url );
+    $req->accept_decodable;
     $req->content($file_content);
     $req->header( 'Content-Type', $content_type );
 
@@ -274,8 +275,7 @@ sub watched {
     return $self->query($u);
 }
 
-no Any::Moose;
-__PACKAGE__->meta->make_immutable;
+no Moo;
 
 1;
 __END__
