@@ -1,8 +1,8 @@
 package Net::GitHub::V3::Search;
 
-use Any::Moose;
+use Moo;
 
-our $VERSION = '0.49';
+our $VERSION = '0.60';
 our $AUTHORITY = 'cpan:FAYLAND';
 
 use URI::Escape;
@@ -20,8 +20,7 @@ my %__methods = (
 );
 __build_methods(__PACKAGE__, %__methods);
 
-no Any::Moose;
-__PACKAGE__->meta->make_immutable;
+no Moo;
 
 1;
 __END__
@@ -67,8 +66,6 @@ L<http://developer.github.com/v3/search/>
     my %data = $search->email('fayland@gmail.com');
     print Dumper(\$data{user});
 
-=item
-
 =back
 
 =head1 AUTHOR & COPYRIGHT & LICENSE
